@@ -1,5 +1,5 @@
 import logging
-from .slack.slack import push_noti
+from .slack import push_noti
 
 
 def _add_logger_level(levelname, level, *, func_name=None):
